# Withdrawal Policies

Classes implementing different withdrawal strategies.

## Base Policy

::: fundedness.withdrawals.base.WithdrawalPolicy

::: fundedness.withdrawals.base.BaseWithdrawalPolicy

## Fixed SWR

::: fundedness.withdrawals.fixed_swr.FixedRealSWRPolicy

## Percentage of Portfolio

::: fundedness.withdrawals.fixed_swr.PercentOfPortfolioPolicy

## Guardrails

::: fundedness.withdrawals.guardrails.GuardrailsPolicy

## Variable Percentage Withdrawal

::: fundedness.withdrawals.vpw.VPWPolicy

## RMD-Style

::: fundedness.withdrawals.rmd_style.RMDStylePolicy
